#tree a{
	
	text-transform:Capitalize;
	font-size:16px;
	
	}

#tree ul, #tree li { 
display:block;
list-style-type:none;

}
#tree li { 
display:block;
margin-left:-4px;
background:url(tree-default-line.gif) -7px 0px no-repeat;
padding-left:2px;
white-space:nowrap;


}

.hidden{
	 display:none;
	 }

ul.hidden{
	
	display:none;
	}
.display{
	
	display:block;
	padding:0 0 0 0;
	margin:0 0 0 0;
	
	}

#tree ul{
	padding-left:-4px;
	
	}

#tree img.add_delete{
   margin-left:-5px;
   background-color: white;

}
	
#tree .collapse{
	background: url(../images/plus.gif) 0px 0px no-repeat;
	margin-left:-5px;
	margin-top:10px;
	width:20px;
	background-color: white;
	
	
	
	}
#tree .expand{
	background: url(../images/minus.gif) 0px 0px no-repeat;
	margin-left:-5px;
	margin-top:10px;
	width:20px;
	background-color: white;
	
	
	
	}
	.collapse a{
	margin-left:7px;
	
	}
	
	.expand a{
	margin-left:7px;
	
	}
#tree .collapse img{
	
	z-index:9089;
	}
#tree a:focus { 
	outline: none; 
	}
body > *[selected="true"] {
    display: block;
}


div.scrollable {
  display:block;
  width:100%;
  overflow:auto;
  height:330px;
}


/* BUTTONS */

.buttons a, .buttons button{
    display:block;
    float:right;
    margin:0 7px 0 0;
    background-color:#f5f5f5;
    border:1px solid #dedede;
    border-top:1px solid #eee;
    border-left:1px solid #eee;

    font-family:"Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
    font-size:11px;
    line-height:130%;
    text-decoration:none;
    font-weight:bold;
    color:#565656;
    cursor:pointer;
    padding:5px 10px 6px 7px; /* Links */
}
.buttons button{
    width:auto;
    overflow:visible;
    padding:4px 10px 3px 7px; /* IE6 */
}
.buttons button[type]{
    padding:5px 10px 5px 7px; /* Firefox */
    line-height:17px; /* Safari */
}
*:first-child+html button[type]{
    padding:4px 10px 3px 7px; /* IE7 */
}
.buttons button img, .buttons a img{
    margin:0 3px -3px 0 !important;
    padding:0;
    border:none;
    width:16px;
    height:16px;
}
.errors{
color: #f00;
font-style: italic;
font-weight: bold;
list-style:none;
font-size:10px;
	
}
img.delete{
   margin-bottom:-3px;
}
.ajax_loading{
    background-image:url("../images/ajax-loader.gif");
    background-repeat:no-repeat;
    background-position: center center;

}
