# Generated by Django 3.1.13 on 2022-02-17 11:02

import django.contrib.gis.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("simple_locations", "0009_auto_20211111_0805"),
    ]

    operations = [
        migrations.CreateModel(
            name="Border",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("geom", django.contrib.gis.db.models.fields.LineStringField(srid=3857)),
                ("area", models.ManyToManyField(to="simple_locations.Area")),
            ],
        ),
    ]
