# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2017-03-30 07:18
from __future__ import unicode_literals

import django.contrib.gis.db.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simple_locations', '0003_auto_20170320_1024'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='facility',
            name='area',
        ),
        migrations.RemoveField(
            model_name='facility',
            name='catchment_areas',
        ),
        migrations.RemoveField(
            model_name='facility',
            name='location',
        ),
        migrations.RemoveField(
            model_name='facility',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='facility',
            name='type',
        ),
        migrations.AlterModelManagers(
            name='area',
            managers=[
            ],
        ),
        migrations.AddField(
            model_name='area',
            name='geom',
            field=django.contrib.gis.db.models.fields.MultiPolygonField(null=True, srid=4326),
        ),
        migrations.DeleteModel(
            name='Facility',
        ),
        migrations.DeleteModel(
            name='FacilityType',
        ),
    ]
